@@ -19,6 +19,7 @@ import sys
 
 
 PY26 = sys.version_info[:2] < (2, 7)
+PY34 = sys.version_info[:2] < (3, 5)
 
 
 # Setup logger
@@ -71,6 +72,17 @@ else:
 """)
 
 
+def raise_from_none(exc):  # pragma: no cover
+    """
+    Convenience function to raise from None in a Python 2/3 compatible manner
+    """
+    raise exc
+
+
+if sys.version_info[0] >= 3:  # pragma: no branch
+    exec('def raise_from_none(exc):\n    raise exc from None')  # pylint: disable=exec-used
+
+
 class ClassProperty(object):
     """
     Property decorator for class methods
@@ -192,7 +204,7 @@ class DictWithDotNotation(dict):
         try:
             return self[name]
         except KeyError:
-            raise AttributeError("'dict' object has no attribute '%s'" % name)
+            raise_from_none(AttributeError("'dict' object has no attribute '%s'" % name))
 
 
 class abstractstaticmethod(staticmethod):  # noqa: N801  # pylint: disable=invalid-name
