@@ -20,6 +20,7 @@ from tests import OUTPUT, TestCase, unittest
 
 
 NO_ASYNC = sys.version_info[:2] < (3, 5)
+PY2 = sys.version_info[0] < 3
 
 
 # pylint: disable=protected-access, no-member
@@ -193,6 +194,38 @@ class TestPlugin(TestCase):
         # Clear plugins from module
         parent.get_plugins().clear()
 
+    def test_plugin_type(self):
+        """plugin_type property is passed from parent"""
+        self.assertEqual(self.parent.plugin_type, 'test_parent')
+
+        class Child(self.parent):
+            """Child has same plugin_type"""
+
+        self.assertEqual(Child.plugin_type, 'test_parent')
+
+    def test_plugin_group_none(self):
+        """plugin_group property is passed from parent"""
+        self.assertEqual(self.parent.plugin_group, None)
+
+        class Child(self.parent):
+            """Child has same plugin_group"""
+
+        self.assertEqual(Child.plugin_group, None)
+
+    def test_plugin_group(self):
+        """plugin_group property is passed from parent"""
+
+        @parent.Parent('test_parent', group='A-Team')
+        class Parent(object):
+            """Parent"""
+
+        self.assertEqual(Parent.plugin_group, 'A-Team')
+
+        class Child(Parent):
+            """Child has same plugin_group"""
+
+        self.assertEqual(Child.plugin_group, 'A-Team')
+
     def test_alias_none(self):
         """name attribute is class name"""
 
@@ -363,6 +396,26 @@ class TestPluginType(TestCase):
         self.prop(Parent, 'Does not contain required method')
         self.attr(Parent, 'Does not contain required method')
         self.coroutine(Parent)
+        self.type_hints_1(Parent)
+        self.type_hints_2(Parent)
+
+    def test_multiple_methods(self):
+        """Method required in subclass"""
+
+        @parent.Parent('test_parent')
+        class Parent(object):
+            """Parent with abstract class method"""
+
+            @abstractmethod
+            def abstract2(self):
+                """Abstract method"""
+
+            @abstractmethod
+            def abstract(self):
+                """Abstract method"""
+
+        self.meth(Parent, 'Does not contain required method')
+        self.multiple(Parent)
 
     def test_abs_method_argspec(self):
         """Method argument spec must match"""
@@ -499,6 +552,28 @@ class TestPluginType(TestCase):
         self.attr(Parent, 'Does not contain required method')
         self.coroutine(Parent)
 
+    @unittest.skipIf(PY2, 'Requires Python 3+')
+    def test_type_annotations(self):
+        """If parent and child have annotations they must match"""
+
+        @parent.Parent('test_parent')
+        class Parent(object):
+            """Parent with typed method"""
+
+            class_definition = textwrap.dedent('''\
+            @abstractmethod
+            def abstract(self) -> str:
+                """Method with type annotations"""
+            ''')
+
+            local_rtn = {}
+            exec(class_definition, globals(), local_rtn)  # pylint: disable=exec-used
+            abstract = local_rtn['abstract']
+
+        self.meth(Parent)
+        self.type_hints_1(Parent)
+        self.type_hints_2(Parent, 'Type annotations differ')
+
     def check_method(self, parent_class, error, child, e):
         """Check child methods"""
 
@@ -537,6 +612,22 @@ class TestPluginType(TestCase):
 
         self.check_method(parent_class, error, Meth, e)
 
+    def multiple(self, parent_class, error=None):
+        """Test abstract method is a regular method"""
+
+        with warnings.catch_warnings(record=True) as e:
+
+            class Meth(parent_class):
+                """Only has regular method"""
+
+                def abstract(self):
+                    """Regular method"""
+
+                def abstract2(self):
+                    """Regular method"""
+
+        self.check_method(parent_class, error, Meth, e)
+
     def static(self, parent_class, error=None):
         """Test abstract method is a static method"""
 
@@ -619,6 +710,50 @@ class TestPluginType(TestCase):
 
         self.check_method(parent_class, error, Coroutine, e)
 
+    def type_hints_1(self, parent_class, error=None):
+        """Test abstract method has type annotations"""
+
+        if PY2:
+            return
+
+        with warnings.catch_warnings(record=True) as e:
+
+            class_definition = textwrap.dedent('''\
+            class TypeHints1(parent_class):
+                """Has type annotations"""
+
+                def abstract(self) -> str:
+                    """Method with type annotations"""
+            ''')
+
+            local_rtn = {'parent_class': parent_class}
+            exec(class_definition, globals(), local_rtn)  # pylint: disable=exec-used
+            TypeHints1 = local_rtn['TypeHints1']  # pylint: disable=invalid-name
+
+        self.check_method(parent_class, error, TypeHints1, e)
+
+    def type_hints_2(self, parent_class, error=None):
+        """Test abstract method has type annotations"""
+
+        if PY2:
+            return
+
+        with warnings.catch_warnings(record=True) as e:
+
+            class_definition = textwrap.dedent('''\
+            class TypeHints2(parent_class):
+                """Has type annotations"""
+
+                def abstract(self) -> int:
+                    """Method with type annotations"""
+            ''')
+
+            local_rtn = {'parent_class': parent_class}
+            exec(class_definition, globals(), local_rtn)  # pylint: disable=exec-used
+            TypeHints2 = local_rtn['TypeHints2']  # pylint: disable=invalid-name
+
+        self.check_method(parent_class, error, TypeHints2, e)
+
     def test_duplicate_parents(self):
         """Parents with the same plugin type should raise an error"""
 
